from mssql_imports.models import QueryConfig


queries = [

    QueryConfig(
        name="general_counters",
        query="""
SELECT
       LTRIM(RTRIM(object_name)) as object_name,
       LTRIM(RTRIM(counter_name)) as counter_name,
       cntr_value
FROM sys.dm_os_performance_counters
WHERE (instance_name = '_Total' OR instance_name = '')
AND counter_name IN (
    'Average Latch Wait Time (ms)',
    'Latch Waits/sec',
    'Logins/sec',
    'Processes blocked',
    'User Connections',
    'Lock Wait Time (ms)',
    'Lock Timeouts/sec',
    'Lock Timeouts/sec',
    'Lock Waits/sec',
    'Number of Deadlocks/sec',
    'Batch Requests/sec',
    'SQL Compilations/sec',
    'SQL Re-Compilations/sec',
    'Target Server Memory (KB)',
    'Total Server Memory (KB)',
    'Connection Memory (KB)',
    'Memory Grants Outstanding',
    'Memory Grants Pending',
    'Page reads/sec',
    'Page writes/sec',
    'Page life expectancy',
    'Free list stalls/sec',
    'Checkpoint pages/sec',
    'Bytes Sent to Replica/sec')
""",
        will_run_now=True,
        dimension_columns=["counter_name"],
        value_columns=["cntr_value"],
    ),
    QueryConfig(
        name="database_counters",
        query="""
SELECT
       LTRIM(RTRIM(instance_name)) as instance_name,
       LTRIM(RTRIM(object_name)) as object_name,
       LTRIM(RTRIM(counter_name)) as counter_name,
       cntr_value
FROM sys.dm_os_performance_counters
WHERE ({instance_filter})
AND counter_name IN (
    'Log File(s) Size (KB)',
    'Log File(s) Used Size (KB)',
    'Log Flush Waits/sec',
    'Log Growths',
    'Log Shrinks',
    'Log Truncations',
    'Percent Log Used',
    'Transactions/sec'
)
""",
        will_run_now=True,
        dimension_columns=["counter_name"],
        value_columns=["cntr_value"],
    ),    QueryConfig(
        name="buffer_manager",
        query="""
SELECT 'BufferCacheHitPercent' AS counter_name, 
( a.cntr_value * 1.0 / b.cntr_value ) * 100.0 AS cntr_value
FROM   sys.dm_os_performance_counters a
JOIN (
        SELECT cntr_value, object_name
        FROM   sys.dm_os_performance_counters
        WHERE  counter_name = 'Buffer cache hit ratio base') b
    ON a.object_name = b.object_name
    WHERE  a.counter_name = 'Buffer cache hit ratio'
""",
        will_run_now=True,
        dimension_columns=["counter_name"],
        value_columns=["cntr_value"],
    ),
]
